@@ -45,10 +45,12 @@ void
 _asn1_error_description_value_not_found(node_asn *node,char *ErrorDescription)
 {
 
-  strcpy(ErrorDescription,":: value of element '");
+  if (ErrorDescription == NULL) return;
+
+  Estrcpy(ErrorDescription,":: value of element '");
   _asn1_hierarchical_name(node,ErrorDescription+strlen(ErrorDescription),
 			  MAX_ERROR_DESCRIPTION_SIZE-40);
-  strcat(ErrorDescription,"' not found");
+  Estrcat(ErrorDescription,"' not found");
 
 }
 
@@ -231,11 +233,11 @@ _asn1_objectid_der(unsigned char *str,unsigned char *der,int *der_len)
   temp=(char *) malloc(strlen(str)+2);
 
   strcpy(temp, str);
-  strcat(temp, " ");
+  strcat(temp, ".");
 
   counter=0;
   n_start=temp;
-  while((n_end=strchr(n_start,' '))){
+  while((n_end=strchr(n_start,'.'))){
     *n_end=0;
     val=strtoul(n_start,NULL,10);
     counter++;
@@ -324,7 +326,14 @@ _asn1_complete_explicit_tag(node_asn *node,unsigned char *der,int *counter)
 
   if(node->type&CONST_TAG){
     p=node->down;
-    while(p){
+    /* When there are nested tags we must complete them reverse to
+       the order they were created. This is because completing a tag
+       modifies alla date within it, including the incomplete tags 
+       which store buffer positions -- simon@josefsson.org 2002-09-06
+    */
+    while(p->right)
+      p=p->right;
+    while(p && p!=node->down->left){
       if(type_field(p->type)==TYPE_TAG){
 	if(p->type&CONST_EXPLICIT){
 	  len2=strtol(p->name,NULL,10);
@@ -341,7 +350,7 @@ _asn1_complete_explicit_tag(node_asn *node,unsigned char *der,int *counter)
 	  }
 	}
       }
-      p=p->right;
+      p=p->left;
     }
   }
 }
@@ -435,6 +444,9 @@ _asn1_insert_tag_der(node_asn *node,unsigned char *der,int *counter)
     case TYPE_OCTET_STRING:
       _asn1_tag_der(UNIVERSAL,TAG_OCTET_STRING,der+*counter,&tag_len);
       break;
+    case TYPE_GENERALSTRING:
+      _asn1_tag_der(UNIVERSAL,TAG_GENERALSTRING,der+*counter,&tag_len);
+      break;
     case TYPE_BIT_STRING:
       _asn1_tag_der(UNIVERSAL,TAG_BIT_STRING,der+*counter,&tag_len);
       break;
@@ -735,6 +747,12 @@ asn1_der_coding(ASN1_TYPE element,const char *name,unsigned char *der,int *len,
       counter+=len3+len2;
       move=RIGHT;
       break;
+    case TYPE_GENERALSTRING:
+      len2=_asn1_get_length_der(p->value,&len3);
+      memcpy(der+counter,p->value,len3+len2);
+      counter+=len3+len2;
+      move=RIGHT;
+      break;
     case TYPE_BIT_STRING:
       len2=_asn1_get_length_der(p->value,&len3);
       memcpy(der+counter,p->value,len3+len2);
