@@ -28,7 +28,7 @@
 extern "C" {
 #endif
 
-#define LIBASN1_VERSION "0.2.0"
+#define LIBASN1_VERSION "0.2.1"
 
 #include <sys/types.h>
 #include <time.h>
@@ -71,6 +71,31 @@ typedef int asn1_retCode;  /* type returned by libasn1 functions */
 #define ASN1_PRINT_NAME_TYPE_VALUE  3
 #define ASN1_PRINT_ALL              4
 
+/*****************************************/
+/* Constants returned by asn1_read_tag   */
+/*****************************************/
+#define ASN1_CLASS_UNIVERSAL        1
+#define ASN1_CLASS_APPLICATION      2
+#define ASN1_CLASS_CONTEXT_SPECIFIC 3
+#define ASN1_CLASS_PRIVATE          4
+
+
+/*****************************************/
+/* Constants returned by asn1_read_tag   */
+/*****************************************/
+#define ASN1_TAG_BOOLEAN          0x01
+#define ASN1_TAG_INTEGER          0x02
+#define ASN1_TAG_SEQUENCE         0x10
+#define ASN1_TAG_SET              0x11
+#define ASN1_TAG_OCTET_STRING     0x04
+#define ASN1_TAG_BIT_STRING       0x03
+#define ASN1_TAG_UTCTime          0x17
+#define ASN1_TAG_GENERALIZEDTime  0x18
+#define ASN1_TAG_OBJECT_ID        0x06
+#define ASN1_TAG_ENUMERATED       0x0A
+#define ASN1_TAG_NULL             0x05
+#define ASN1_TAG_GENERALSTRING    0x1B
+
 
 /******************************************************/
 /* Structure definition used for the node of the tree */
@@ -145,6 +170,12 @@ asn1_retCode asn1_expand_any_defined_by(ASN1_TYPE definitions,
 asn1_retCode asn1_expand_octet_string(ASN1_TYPE definitions,ASN1_TYPE *element,
 	       const char *octetName,const char *objectName);
 
+asn1_retCode asn1_read_tag(node_asn *root,const char *name,int *tag, 
+			   int *class);
+
+asn1_retCode asn1_find_structure_from_oid(ASN1_TYPE definitions,
+		    const char *oidValue,char *structureName);
+
 const char* libtasn1_strerror(asn1_retCode error);
 
 void libtasn1_perror(asn1_retCode error);
